import com.ibm.eNetwork.ECL.*;

public class SALogon extends Thread implements HostLPConstants, ECLPSNotify
{

  static final SAVMLogin vmLogin  = new SAVMLogin();
  static final SAMore    more     = new SAMore();
  static final SAReady   ready    = new SAReady();
  static final SAMsg10   msg10    = new SAMsg10();
  static final ScreenState MyScreenState    = new ScreenState();
  Object myLock = new Object();

  ECLPS ps;
  ECLOIA oia;
  CLogonData LogonData;
  Object EndingCallLock;

  public SALogon(ECLPS InitialPS, ECLOIA InitialOIA, CLogonData InitialLogonData,
                 Object InitialCallLock)

  { // the data that we care about.
    ps = InitialPS;
    oia = InitialOIA;
    LogonData = InitialLogonData;

    // Need to keep track of what state the screen is in.
    MyScreenState.UpdateState(SS_INIT);

    EndingCallLock = InitialCallLock;
  }

  public void run()
  {
     try
     { // Register with the ECL that we want to be notified whenever the
       // screen is updated.  When the event occurs we are NOT assured that
       // a "whole" screen of data is present, only that there screen has
       // been updated in some way.

       ps.RegisterPSEvent(this);

     }
     catch (Exception ECLErr)
     { // Use the GetMsgText() method to print out error messages
       System.out.println("SALogon: Registration ECLErr Exception");
       System.out.println("ECLErr Exception from RegisterPSEvent constructor --> " + ECLErr.toString());

     }

     // The screen processing will be handled asynchronously whenever
     // notification of screen updates occur.  So the run method will now wait
     // until it is signalled that the logon has completed.
     synchronized(myLock)
     {
       while (MyScreenState.GetState() != SS_LOGON_FINISHED)
       { try
         {
           myLock.wait();
         }
         catch(InterruptedException e)
         { System.out.println("SALogon: wait Exception");
         }
       }
     }

     // Tell the waiting thread (the "main" thread in the LogonLaunchApp)
     // that we have completed the logon.
     synchronized(EndingCallLock)
     {
       EndingCallLock.notify();
     }
  }


  public void NotifyEvent(ECLPS ps)
  {
     // Look at PS to deterimine which screen we're on
     // take appropriate action.

     // Each of these screen recognition and action "methods"
     // are seperated in their own classes.  See the files
     // ScreenAction.java, SAMsg10, SAVMLogin.java, SAMore.java
     // and SAReady.java

     // If we recognize that this is the first screen
     // then process it, and return.
     if (msg10.recognizes(ps, oia ,MyScreenState,LogonData))
     { return;
     }

     // If we recognize that this is the main logon screen
     // then process it, and return.
     if (vmLogin.recognizes(ps, oia ,MyScreenState,LogonData))
     { return;
     }

     // If this is an intermediate screen (after logon we are
     // cycling through the user's startup sequence), then
     // recognize when the screen needs to be cleared so more
     // processing can occur.
     if (more.recognizes(ps, oia, MyScreenState))
     { return;
     }

     // For our systems, we know that the logon has completed
     // when the "Ready;" prompt appears on the screen.  So if
     // we recognize that, assume we're logged in.
     if (ready.recognizes(ps, oia, MyScreenState))
     {
       // This means the logon is complete, so update our
       // screen state variable.
       if (MyScreenState.GetState() == SS_LOGON_FINISHED)
       {
         try
         {
           // This class will no longer process screens, so unregister
           // with PS.
           ps.UnregisterPSEvent(this);
         }
         catch(Exception e)
         { System.out.println("SALogon: UnRegistration Exception");
         }

         // Tell the run method that we're done.
         synchronized(myLock)
         {
           myLock.notify();
         }
       }
       return;
     }
  }

  public void NotifyStop(ECLPS eclps, int reason)
  {
  }

  public void NotifyError(ECLPS eclps, ECLErr e)
  {
  }
}
