import com.ibm.eNetwork.ECL.*;

// This is a base class for handling screens.
// The idea is that each noteworthy screen needs to be
// recognized and an action taken on that screen.

public class ScreenAction
{
  String[] buffer = null;
  int rows;
  int startPos;

  public ScreenAction()
  {
  }

  // Set up what characters will be used (the footprint)
  // to recognize the particular screen.
  public ScreenAction(String[] screenRect)
  {
     SetFootprint(screenRect, 1);
  }

  public ScreenAction(String[] screenRect, int startingPos)
  {
     SetFootprint(screenRect, startingPos);
  }

  // Set up what characters will be used (the footprint)
  // to recognize the particular screen.
  // the starting postion denotes where in the screen to start
  // looking for this footprint
  public void SetFootprint(String screenRect[], int startingPos)
  {
     int i;

     startPos = startingPos;
     rows = screenRect.length;
     buffer = new String[rows];

     for (i = 0; i < rows; i++)
        buffer[i] = new String(screenRect[i]);
  }


  public boolean recognizes(ECLPS ps, ECLOIA oia, ScreenState MyScreenState)
  {
     // Start at the desired position on the screen, and check to see
     // if the strings listed in the footprint, are on this screen.
     // Notice that this function is basically the same as those
     // other SAVMLogin.java, SAMore.java, SAReady and SAFilelResults classes,
     // but it is usually overriden by a recognize
     // function which takes input parameters that will be used once
     // the screen is recognized.

     int i;
     int pos = startPos;

     for (i = 0; i < rows; i++)
     {  // Search for the strings in the order they were given.
        // If one does not appear, then this screen does not
        // match the desired footprint.
        pos = ps.SearchText(buffer[i], pos, ps.SEARCH_FORWARD);
        if (pos == 0)
           return false;
     }

     // If we made it here, then the screen was recognized.
     // Wait for presentation layer to "settle down"
     // as described before in SALogon.java
     try { Thread.sleep(100); }
     catch (InterruptedException e)
     { /* System.out.println("SAFilel: catch sleep InterruptedException"); */ }
     while (oia.InputInhibited() != oia.INHIBIT_NOTINHIBITED)
       try { Thread.sleep(100); }
       catch (InterruptedException e)
       { /* System.out.println("SAFilel: catch sleep InterruptedException"); */ }

     // Once the screen is recognized, then take some action on it.
     TakeActionOnScreen(ps, MyScreenState);

     return true;
  }

  public void TakeActionOnScreen (ECLPS ps, ScreenState MyScreenState)
  {
    // This function is usually overridden.  But the default action
    // to take on a screen will be to send an enter.
    try
    { ps.SendKeys(ps.ENTER_STR);
    }
    catch(Exception e)
    { System.out.println("ScreenAction: SendKeys Exception"); }

  }
}
