//-------------------------------------------------------------------
// ECLPS.GetScreen()
//
// Get text and other planes of data from the presentation space.
//-------------------------------------------------------------------
import java.util.Properties;
import com.ibm.eNetwork.ECL.*;

public class Sample64 implements ECLAppletInterface
{

   /*********************************************************************
   * Constructor
   */
   public Sample64()
   {
   }


   /*********************************************************************
   * Method called by Host On-Demand when the applet is initialized.
   * This method is defined as part of the ECLAppletInterface
   */
   public void init(ECLSession s)
   {

      ECLPS  ps;                // PS object
      char[] plane;             // Field plane data
      int len, rows, cols;

      StringBuffer buff;
      short l, m;

      ps = s.GetPS();

      len  = ps.GetSize();
      rows = ps.GetSizeRows();
      cols = ps.GetSizeCols();

      buff = new StringBuffer(cols*4);

      // Note text buffer needs extra byte for null terminator
      plane = new char[len  + 1];

      try {
         ///////////////////////////////////
         // Get entire screen (text)
         ///////////////////////////////////
         ps.GetScreen(plane, plane.length, ECLPS.TEXT_PLANE);

         System.out.println("Printing text plane data:");

         for (int row=0; row < rows; row++)
            System.out.println(String.valueOf(plane, row*cols, cols));

         System.out.println("Printing text plane as HEX:");
         printPlane(plane, rows, cols);

         ///////////////////////////////////
         // Get entire field plane
         ///////////////////////////////////
         ps.GetScreen(plane, plane.length, ECLPS.FIELD_PLANE);
         System.out.println("Printing field plane data:");
         printPlane(plane, rows, cols);

         ///////////////////////////////////
         // Get entire color plane
         ///////////////////////////////////
         ps.GetScreen(plane, plane.length, ECLPS.COLOR_PLANE);
         System.out.println("Printing color plane data:");
         printPlane(plane, rows, cols);

         ///////////////////////////////////
         // Get entire extended field plane
         ///////////////////////////////////
         ps.GetScreen(plane, plane.length, ECLPS.EXFIELD_PLANE);
         System.out.println("Printing extended field plane data:");
         printPlane(plane, rows, cols);

         ps.GetScreen(plane, plane.length, cols+1, cols, ECLPS.TEXT_PLANE);   // Get line 2 screen
         
         // Parallel methods which do not return the duplicate DBCS characters 
         // contained in the Text Plane for DBCS sessions.
         //ps.GetString(plane, plane.length, 1, 1, cols);       // Get line 1 screen
         //ps.GetString(plane, plane.length, cols+1, cols);     // Get line 2 screen
         //ps.GetString(plane, plane.length);                   // Get entire screen (text)


         System.out.println("Line 2 of the screen");
         System.out.println(String.valueOf(plane, 0, cols));

      } catch (ECLErr e) { System.out.println("Sample64(): " + e.GetMsgText()); }

   } // end sample
   
   
   // Method to print plane information in HEX
   void printPlane(char[] plane, int rows, int cols)
   {
      for (int row=0; row < rows; row++)
      {
         for (int col=0; col <= cols; col++)
         {
            if (plane[row*cols+col] < 16)
               System.out.print("0");

            System.out.print(Integer.toHexString(plane[row*cols+col]) + " ");
         }

         System.out.println("");
      }
   }


}
